@@ -11,7 +11,6 @@ import getpass
 import json
 import re
 import sys
-import platform
 import datetime
 import time
 from time import sleep
@@ -893,7 +892,7 @@ def tgpt2_():
 @click.option(
     "-n",
     "--new",
-    help="Override the filepath contents",
+    help="Overwrite the filepath contents",
     is_flag=True,
 )
 @click.option(
@@ -1185,37 +1184,37 @@ def generate(
         provider,
         quiet,
     )
+    prompt = prompt if prompt else ""
     if with_copied:
-        sep = "\n" if prompt else ""
-        prompt = prompt + sep + clipman.get()
-        assert prompt.strip() != sep, "No copied text found, issue prompt"
+        copied_placeholder = "{{copied}}"
+        last_copied_text = clipman.get()
+        assert last_copied_text, "No copied text found, issue prompt"
 
-    if not prompt and platform.system() != "Windows":
-        # Let's try to read piped input
-        import signal
-
-        def timeout_handler(signum, frame):
-            raise TimeoutError("Timed out while waiting for input")
-
-        signal.signal(signal.SIGALRM, timeout_handler)
-        signal.alarm(
-            1
-        )  # Not to wait for long. I was thinking of making it 2 but I found it awful, what's your take?
-        try:
-            prompt = click.get_text_stream("stdin").read()
-        except TimeoutError as e:
-            help_info = (
-                "Usage: pytgpt generate [OPTIONS] PROMPT\n"
-                "Try 'pytgpt generate --help' for help.\n"
-                "Error: Missing argument 'PROMPT'.\n"
-            )
-            click.secho(
-                help_info
-            )  # Let's try to mimic the click's missing argument help info
-            sys.exit(1)
+        if copied_placeholder in prompt:
+            prompt = prompt.replace(copied_placeholder, last_copied_text)
         else:
-            signal.alarm(0)  # Reset the alarm if input is read successfully
-            # Just incase the previous timeout was not 0
+            sep = "\n" if prompt else ""
+            prompt = prompt + sep + last_copied_text
+
+    if not prompt and sys.stdin.isatty():  # No prompt issued and no piped input
+        help_info = (
+            "Usage: pytgpt generate [OPTIONS] PROMPT\n"
+            "Try 'pytgpt generate --help' for help.\n"
+            "Error: Missing argument 'PROMPT'."
+        )
+        click.secho(
+            help_info
+        )  # Let's try to mimic the click's missing argument help info
+        sys.exit(1)
+
+    if not sys.stdin.isatty():  # Piped input detected - True
+        # Let's try to read piped input
+        stream_text = click.get_text_stream("stdin").read()
+        stream_placeholder = "{{stream}}"
+        if stream_placeholder in prompt:
+            prompt = prompt.replace(stream_placeholder, stream_text)
+        else:
+            prompt = prompt + "\n" + stream_text if prompt else stream_text
 
     clear_history_file(filepath, new)
     prompt = Optimizers.code(prompt) if code else prompt
